# Generated by roxygen2: do not edit by hand

export(ChisqrGoodnessOfFit)
export(Df2RJafrocDataset)
export(DfBinDataset)
export(DfCreateCorCbmDataset)
export(DfExtractCorCbmDataset)
export(DfExtractDataset)
export(DfFroc2Lroc)
export(DfFroc2Roc)
export(DfLroc2Froc)
export(DfLroc2Roc)
export(DfReadCrossedModalities)
export(DfReadDataFile)
export(DfSaveDataFile)
export(DfWriteExcelDataFile)
export(FitBinormalRoc)
export(FitCbmRoc)
export(FitCorCbm)
export(FitRsmRoc)
export(PlotBinormalFit)
export(PlotCbmFit)
export(PlotEmpiricalOperatingCharacteristics)
export(PlotRsmOperatingCharacteristics)
export(RSM_LLF)
export(RSM_NLF)
export(RSM_pdfD)
export(RSM_pdfN)
export(RSM_wLLF)
export(RSM_xROC)
export(RSM_yROC)
export(SimulateCorCbmDataset)
export(SimulateFrocDataset)
export(SimulateFrocFromLrocDataset)
export(SimulateLrocDataset)
export(SimulateRocDataset)
export(SsFrocNhRsmModel)
export(SsPowerGivenJK)
export(SsPowerGivenJKDbmVarCom)
export(SsPowerGivenJKOrVarCom)
export(SsPowerTable)
export(SsSampleSizeKGivenJ)
export(StSignificanceTesting)
export(StSignificanceTestingCadVsRad)
export(StSignificanceTestingCrossedModalities)
export(UtilAnalyticalAucsRSM)
export(UtilAucBinormal)
export(UtilAucCBM)
export(UtilAucPROPROC)
export(UtilDBM2ORVarCom)
export(UtilFigureOfMerit)
export(UtilIntrinsic2RSM)
export(UtilLesionDistrVector)
export(UtilLesionWeightsMatrixDataset)
export(UtilLesionWeightsMatrixLesDistr)
export(UtilMeanSquares)
export(UtilOR2DBMVarCom)
export(UtilORVarComponentsFactorial)
export(UtilOutputReport)
export(UtilPseudoValues)
export(UtilRSM2Intrinsic)
export(UtilVarComponentsDBM)
export(isBinnedDataset)
export(isValidDataset)
import(ggplot2)
import(openxlsx)
import(readxl)
import(utils)
importFrom(Rcpp,cppFunction)
importFrom(Rcpp,evalCpp)
importFrom(bbmle,mle2)
importFrom(binom,binom.confint)
importFrom(dplyr,between)
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,theme)
importFrom(mvtnorm,pmvnorm)
importFrom(mvtnorm,rmvnorm)
importFrom(numDeriv,hessian)
importFrom(numDeriv,jacobian)
importFrom(stats,approx)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,dbinom)
importFrom(stats,dnorm)
importFrom(stats,integrate)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,pchisq)
importFrom(stats,pf)
importFrom(stats,pnorm)
importFrom(stats,pt)
importFrom(stats,qchisq)
importFrom(stats,qf)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,rbinom)
importFrom(stats,rnorm)
importFrom(stats,rpois)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,t.test)
importFrom(stats,uniroot)
importFrom(stats,var)
importFrom(stringr,str_length)
importFrom(stringr,str_trim)
importFrom(tools,file_ext)
importFrom(tools,file_path_sans_ext)
importFrom(utils,packageDescription)
importFrom(utils,read.delim)
useDynLib(RJafroc)
